@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <math.h>
+#include <time.h>
 
 void core_1d(double *H, double *t, int *n, int *k , double *res)
 {
@@ -8,15 +9,15 @@ void core_1d(double *H, double *t, int *n, int *k , double *res)
   double tmp1,tmp2,tmp3,tmp,R,theta,U;
   
   R=0;
-  srand48(time(NULL));
+  srand(time(NULL));
   
   /* Loop over the terms of the sum (de 0 to n-1) */
   for (l=0;l<*n;l++)
     {
-      theta = drand48();
+      theta = rand()/(float)RAND_MAX;
       U = 1;
-      if (drand48()<0.5) {U=-1;}
-      R = R - log(drand48());
+      if ((rand()/(float)RAND_MAX) < 0.5) {U=-1;}
+      R = R - log(rand()/(float)RAND_MAX);
       /* Loop over each discretization points (0  k-1) */
       for (i=0;i<*k;i++)
 	{
